SqlJournalTransaction

Struct SqlJournalTransaction 

pub struct SqlJournalTransaction { /* private fields */ }
A PostgreSQL transaction for workflow storage.

All operations are performed within the transaction and only become visible when commit() is called. If the transaction is dropped without committing, all operations are rolled back.

Implementations

Source

impl SqlJournalTransaction

pub async fn execute( &self, query: Query<'_, Postgres, PgArguments>, ) -> Result<PgQueryResult, ClusterError>

Execute a raw SQL query within this transaction.

This allows activities to run arbitrary SQL statements that will be committed or rolled back together with entity state changes.

Example
#[activity]
async fn transfer(&mut self, to: String, amount: i64) -> Result<(), ClusterError> {
    self.state.balance -= amount;
     
    if let Some(tx) = ActivityScope::sql_transaction().await {
        tx.execute(
            sqlx::query("INSERT INTO transfers (from_id, to_id, amount) VALUES ($1, $2, $3)")
                .bind(&self.id)
                .bind(&to)
                .bind(amount)
        ).await?;
    }
    Ok(())
}
pub async fn fetch_one<'q, O>( &self, query: QueryAs<'q, Postgres, O, PgArguments>, ) -> Result<O, ClusterError>
where O: Send + Unpin + for<'r> FromRow<'r, PgRow>,

Fetch a single row from a SQL query within this transaction.

pub async fn fetch_optional<'q, O>( &self, query: QueryAs<'q, Postgres, O, PgArguments>, ) -> Result<Option<O>, ClusterError>
where O: Send + Unpin + for<'r> FromRow<'r, PgRow>,

Fetch an optional row from a SQL query within this transaction.

pub async fn fetch_all<'q, O>( &self, query: QueryAs<'q, Postgres, O, PgArguments>, ) -> Result<Vec<O>, ClusterError>
where O: Send + Unpin + for<'r> FromRow<'r, PgRow>,

Fetch all rows from a SQL query within this transaction.